==> eg_particle_interactions-v0.8-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/splash/BlockSplash.java <==
package games.enchanted.eg_particle_interactions.common.particle.splash;

import net.minecraft.class_2338;
import net.minecraft.class_2388;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3999;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import net.minecraft.class_761;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class BlockSplash extends BucketSplash {
    private final class_2338 pos;
    private final float uo;
    private final float vo;

    protected BlockSplash(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_2338 blockPos, class_2680 blockState) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, null);
        this.method_18141(class_310.method_1551().method_1541().method_3351().method_3339(blockState));
        this.pos = blockPos;
        this.uo = this.field_3840.method_43057() * 3.0F;
        this.vo = this.field_3840.method_43057() * 3.0F;

        int tintColour = class_310.method_1551().method_1505().method_1697(blockState, level, blockPos, 0);
        this.field_3861 *= (float)(tintColour >> 16 & 0xFF) / 255.0F;
        this.field_3842 *= (float)(tintColour >> 8 & 0xFF) / 255.0F;
        this.field_3859 *= (float)(tintColour & 0xFF) / 255.0F;

        float particleSize = (float) 0.1255 - (this.field_3840.method_43056() ? 0.01f : 0.02f);
        this.field_17867 = particleSize;
        this.method_3080(particleSize, particleSize);
    }

    @Override
    public @NotNull class_3999 method_18122() {
        return class_3999.field_17827;
    }

    @Override
    protected float method_18133() {
        return this.field_17886.method_4580((this.uo + 1.0F) / 4.0F);
    }

    @Override
    protected float method_18134() {
        return this.field_17886.method_4580(this.uo / 4.0F);
    }

    @Override
    protected float method_18135() {
        return this.field_17886.method_4570(this.vo / 4.0F);
    }

    @Override
    protected float method_18136() {
        return this.field_17886.method_4570((this.vo + 1.0F) / 4.0F);
    }

    @Override
    public int method_3068(float f) {
        int lightColour = super.method_3068(f);
        return lightColour == 0 && this.field_3851.method_22340(this.pos) ? class_761.method_23794(this.field_3851, this.pos) : lightColour;
    }

    public static class Provider implements class_707<class_2388> {
        public Provider(class_4002 spriteSet) {}

        @Nullable
        @Override
        public class_703 createParticle(class_2388 type, @NotNull class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed) {
            return new BlockSplash(level, x, y, z, xSpeed, ySpeed, zSpeed, class_2338.method_49637(x, y, z), type.method_10278());
        }
    }
}

==> eg_particle_interactions-v0.8.4-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/splash/BlockSplash.java <==
package games.enchanted.eg_particle_interactions.common.particle.splash;

import net.minecraft.class_2338;
import net.minecraft.class_2388;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import net.minecraft.class_761;
import org.jetbrains.annotations.Nullable;

public class BlockSplash extends BucketSplash {
    private final class_2338 pos;
    private final float uo;
    private final float vo;

    protected BlockSplash(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_2338 blockPos, class_2680 blockState) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, class_310.method_1551().method_1541().method_3351().method_3339(blockState));
        this.pos = blockPos;
        this.uo = this.field_3840.method_43057() * 3.0F;
        this.vo = this.field_3840.method_43057() * 3.0F;

        int tintColour = class_310.method_1551().method_1505().method_1697(blockState, level, blockPos, 0);
        this.field_3861 *= (float)(tintColour >> 16 & 0xFF) / 255.0F;
        this.field_3842 *= (float)(tintColour >> 8 & 0xFF) / 255.0F;
        this.field_3859 *= (float)(tintColour & 0xFF) / 255.0F;

        float particleSize = (float) 0.1255 - (this.field_3840.method_43056() ? 0.01f : 0.02f);
        this.setScale(particleSize);
        this.method_3080(particleSize, particleSize);
    }

    @Override
    protected ParticleLayer getParticleLayer() {
        return ParticleLayer.TERRAIN;
    }

    @Override
    protected float getU0() {
        return this.sprite.method_4580((this.uo + 1.0F) / 4.0F);
    }

    @Override
    protected float getU1() {
        return this.sprite.method_4580(this.uo / 4.0F);
    }

    @Override
    protected float getV0() {
        return this.sprite.method_4570(this.vo / 4.0F);
    }

    @Override
    protected float getV1() {
        return this.sprite.method_4570((this.vo + 1.0F) / 4.0F);
    }

    @Override
    public int method_3068(float f) {
        int lightColour = super.method_3068(f);
        return lightColour == 0 && this.field_3851.method_22340(this.pos) ? class_761.method_23794(this.field_3851, this.pos) : lightColour;
    }

    public static class Provider implements class_707<class_2388> {
        public Provider(class_4002 spriteSet) {}

        @Override
        public @Nullable class_703 createParticle(
            class_2388 type,
            class_638 level,
            double x,
            double y,
            double z,
            double xSpeed,
            double ySpeed,
            double zSpeed
            //? if minecraft: > 1.21.8 {
            /*, RandomSource random
            *///?}
        ) {
            return new BlockSplash(level, x, y, z, xSpeed, ySpeed, zSpeed, class_2338.method_49637(x, y, z), type.method_10278());
        }
    }
}
